@@ -3,12 +3,13 @@
  * \brief Solves a system of linear equations A*X=B
  *
  * <pre>
- * -- Distributed SuperLU routine (version 4.1) --
+ * -- Distributed SuperLU routine (version 4.3) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * November 1, 2007
  * October 22, 2012
  * October  1, 2014
  * April 5, 2015
+ * December 31, 2015  version 4.3
  * </pre>
  */
 
@@ -478,7 +479,7 @@
  *             > A->ncol: number of bytes allocated when memory allocation
  *                failure occurred, plus A->ncol.
  *
- * See superlu_zdefs.h for the definitions of varioous data types.
+ * See superlu_zdefs.h for the definitions of various data types.
  * </pre>
  */
 
@@ -582,7 +583,7 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 	*info = -6;
     if ( *info ) {
 	i = -(*info);
-	pxerbla("pzgssvx", grid, -*info);
+	pxerr_dist("pzgssvx", grid, -*info);
 	return;
     }
 
@@ -683,20 +684,33 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
             /* Compute the row and column scalings. */
 	    pzgsequ(A, R, C, &rowcnd, &colcnd, &amax, &iinfo, grid);
 
-	    /* Equilibrate matrix A if it is badly-scaled. */
-	    pzlaqgs(A, R, C, rowcnd, colcnd, amax, equed);
+	    if ( iinfo > 0 ) {
+		if ( iinfo <= m ) {
+#if ( PRNTlevel>=1 )
+		    fprintf(stderr, "The " IFMT "-th row of A is exactly zero\n", iinfo);
+#endif
+		} else {
+#if ( PRNTlevel>=1 )
+                    fprintf(stderr, "The " IFMT "-th column of A is exactly zero\n", iinfo-n);
+#endif
+                }
+ 	    } else if ( iinfo < 0 ) return;
 
-	    if ( lsame_(equed, "R") ) {
-		ScalePermstruct->DiagScale = ROW;
-		rowequ = ROW;
-	    } else if ( lsame_(equed, "C") ) {
-		ScalePermstruct->DiagScale = COL;
-		colequ = COL;
-	    } else if ( lsame_(equed, "B") ) {
-		ScalePermstruct->DiagScale = BOTH;
-		rowequ = ROW;
-		colequ = COL;
-	    } else ScalePermstruct->DiagScale = NOEQUIL;
+	    /* Now iinfo == 0 */
+	       /* Equilibrate matrix A if it is badly-scaled. */
+	       pzlaqgs(A, R, C, rowcnd, colcnd, amax, equed);
+
+	       if ( strncmp(equed, "R", 1)==0 ) {
+		  ScalePermstruct->DiagScale = ROW;
+		  rowequ = ROW;
+	       } else if ( strncmp(equed, "C", 1)==0 ) {
+		  ScalePermstruct->DiagScale = COL;
+		  colequ = COL;
+	       } else if ( strncmp(equed, "B", 1)==0 ) {
+		  ScalePermstruct->DiagScale = BOTH;
+		  rowequ = ROW;
+		  colequ = COL;
+	       } else ScalePermstruct->DiagScale = NOEQUIL;
 
 #if ( PRNTlevel>=1 )
 	    if ( !iam ) {
@@ -762,28 +776,39 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 
 	            if ( !iam ) {
 		        /* Process 0 finds a row permutation */
-		        zldperm_dist(job, m, nnz, colptr, rowind, a_GA,
+		        iinfo = zldperm_dist(job, m, nnz, colptr, rowind, a_GA,
 		                perm_r, R1, C1);
 		
-		        MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
-		        if ( job == 5 && Equil ) {
-		            MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
-		            MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+                        MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );
+		        if ( iinfo == 0 ) {
+		            MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
+		            if ( job == 5 && Equil ) {
+		                MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
+		                MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+                            }
 		        }
 	            } else {
-		        MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
-		        if ( job == 5 && Equil ) {
-		            MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
-		            MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+		        MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );
+			if ( iinfo == 0 ) {
+		            MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
+		            if ( job == 5 && Equil ) {
+		                MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
+		                MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+                            }
 		        }
 	            }
 
+	    	    if ( iinfo && job == 5) {
+	                SUPERLU_FREE(R1);
+	        	SUPERLU_FREE(C1);
+   	            }
 #if ( PRNTlevel>=2 )
-	            dmin = dmach("Overflow");
+	            dmin = dmach_dist("Overflow");
 	            dsum = 0.0;
 	            dprod = 1.0;
 #endif
-	            if ( job == 5 ) {
+	            if ( iinfo == 0 ) {
+	              if ( job == 5 ) {
 		        if ( Equil ) {
 		            for (i = 0; i < n; ++i) {
 			        R1[i] = exp(R1[i]);
@@ -831,14 +856,17 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 		        }
 		        SUPERLU_FREE (R1);
 		        SUPERLU_FREE (C1);
-	            } else { /* job = 2,3,4 */
+	              } else { /* job = 2,3,4 */
 		        for (j = 0; j < n; ++j) {
 		            for (i = colptr[j]; i < colptr[j+1]; ++i) {
 			        irow = rowind[i];
 			        rowind[i] = perm_r[irow];
 		            } /* end for i ... */
 		        } /* end for j ... */
-	            } /* end else job ... */
+	              } /* end else job ... */
+                    } else { /* if iinfo != 0 */
+			for (i = 0; i < m; ++i) perm_r[i] = i;
+		    }
 
 #if ( PRNTlevel>=2 )
 	            if ( job == 2 || job == 3 ) {
@@ -935,8 +963,13 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 	      flinfo = get_perm_c_parmetis(A, perm_r, perm_c, nprocs_num,
                                   	   noDomains, &sizes, &fstVtxSep,
                                            grid, &symb_comm);
-	      if (flinfo > 0)
-	          ABORT("ERROR in get perm_c parmetis.");
+	      if (flinfo > 0) {
+#if ( PRNTlevel>=1 )
+	          fprintf(stderr, "Insufficient memory for get_perm_c parmetis\n");
+#endif
+		  *info = flinfo;
+		  return;
+     	      }
 	  } else {
 	      get_perm_c_dist(iam, permc_spec, &GA, perm_c);
           }
@@ -983,7 +1016,7 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 			     	 Glu_persist, Glu_freeable);
 
 	    	stat->utime[SYMBFAC] = SuperLU_timer_() - t;
-	    	if ( iinfo < 0 ) { /* Successful return */
+	    	if ( iinfo <= 0 ) { /* Successful return */
 		    QuerySpace_dist(n, -iinfo, Glu_freeable, &symb_mem_usage);
 #if ( PRNTlevel>=1 )
 		    if ( !iam ) {
@@ -999,11 +1032,13 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 			   	symb_mem_usage.expansions);
 		    }
 #endif
-	    	} else {
-		    if ( !iam ) {
+	    	} else { /* symbfact out of memory */
+#if ( PRNTlevel>=1 )
+		    if ( !iam )
 		        fprintf(stderr,"symbfact() error returns " IFMT "\n",iinfo);
-		    	exit(-1);
-		    }
+#endif
+		    *info = iinfo;
+		    return;
 	        }
 	    } /* end serial symbolic factorization */
 	    else {  /* parallel symbolic factorization */
@@ -1013,8 +1048,13 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 				       &(grid->comm), &symb_comm,
 				       &symb_mem_usage); 
 	    	stat->utime[SYMBFAC] = SuperLU_timer_() - t;
-	    	if (flinfo > 0) 
-	      	    ABORT("Insufficient memory for parallel symbolic factorization.");
+	    	if (flinfo > 0) {
+#if ( PRNTlevel>=1 )
+	      	    fprintf(stderr, "Insufficient memory for parallel symbolic factorization.");
+#endif
+		    *info = flinfo;
+		    return;
+                }
 	    }
 
             /* Destroy GA */
@@ -1165,7 +1205,7 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
     /* ------------------------------------------------------------
        Compute the solution matrix X.
        ------------------------------------------------------------*/
-    if ( nrhs ) {
+    if ( nrhs && *info == 0 ) {
 
 	if ( !(b_work = doublecomplexMalloc_dist(n)) )
 	    ABORT("Malloc fails for b_work[]");
@@ -1347,7 +1387,7 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 	SUPERLU_FREE(b_work);
 	SUPERLU_FREE(X);
 
-    } /* end if nrhs != 0 */
+    } /* end if nrhs != 0 && *info == 0 */
 
 #if ( PRNTlevel>=1 )
     if ( !iam ) printf(".. DiagScale = %d\n", ScalePermstruct->DiagScale);
