@@ -3,9 +3,12 @@
  * \brief Solves a system of linear equations A*X=B,
  *
  * <pre>
- * -- Distributed SuperLU routine (version 1.0) --
+ * -- Distributed SuperLU routine (version 4.3) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * September 1, 1999
+ *
+ * Last modified:
+ * December 31, 2015   version 4.3
  * </pre>
  */
 
@@ -515,7 +518,7 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 	*info = -6;
     if ( *info ) {
 	i = -(*info);
-	pxerbla("pzgssvx_ABglobal", grid, -*info);
+	pxerr_dist("pzgssvx_ABglobal", grid, -*info);
 	return;
     }
 
@@ -623,12 +626,17 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 		    MPI_Bcast( &amax,   1, MPI_DOUBLE, 0, grid->comm );
 		} else {
 		    if ( iinfo > 0 ) {
-			if ( iinfo <= m )
+			if ( iinfo <= m ) {
+#if ( PRNTlevel>=1 )
 			    fprintf(stderr, "The " IFMT "-th row of A is exactly zero\n", 
 				    iinfo);
-			else fprintf(stderr, "The " IFMT "-th column of A is exactly zero\n", 
+#endif
+			} else {
+#if ( PRNTlevel>=1 )
+                            fprintf(stderr, "The " IFMT "-th column of A is exactly zero\n", 
 				     iinfo-n);
-			exit(-1);
+#endif
+                        }
 		    }
 		}
 	    } else {
@@ -639,24 +647,24 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 		    MPI_Bcast( &rowcnd, 1, MPI_DOUBLE, 0, grid->comm );
 		    MPI_Bcast( &colcnd, 1, MPI_DOUBLE, 0, grid->comm );
 		    MPI_Bcast( &amax,   1, MPI_DOUBLE, 0, grid->comm );
-		} else {
-		    ABORT("ZGSEQU failed\n");
-		}
+		} 
 	    }
 	
-	    /* Equilibrate matrix A. */
-	    zlaqgs_dist(A, R, C, rowcnd, colcnd, amax, equed);
-	    if ( lsame_(equed, "R") ) {
-		ScalePermstruct->DiagScale = ROW;
-		rowequ = ROW;
-	    } else if ( lsame_(equed, "C") ) {
-		ScalePermstruct->DiagScale = COL;
-		colequ = COL;
-	    } else if ( lsame_(equed, "B") ) {
-		ScalePermstruct->DiagScale = BOTH;
-		rowequ = ROW;
-		colequ = COL;
-	    } else ScalePermstruct->DiagScale = NOEQUIL;
+            if ( iinfo == 0 ) {
+	        /* Equilibrate matrix A. */
+	        zlaqgs_dist(A, R, C, rowcnd, colcnd, amax, equed);
+	        if ( strncmp(equed, "R", 1)==0 ) {
+		    ScalePermstruct->DiagScale = ROW;
+		    rowequ = ROW;
+	        } else if ( strncmp(equed, "C", 1)==0 ) {
+		    ScalePermstruct->DiagScale = COL;
+		    colequ = COL;
+	        } else if ( strncmp(equed, "B", 1)==0 ) {
+		    ScalePermstruct->DiagScale = BOTH;
+		    rowequ = ROW;
+		    colequ = COL;
+	        } else ScalePermstruct->DiagScale = NOEQUIL;
+            }
 
 #if ( PRNTlevel>=1 )
 	    if ( !iam ) {
@@ -697,27 +705,40 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 
 	    if ( !iam ) {
 		/* Process 0 finds a row permutation for large diagonal. */
-		zldperm_dist(job, m, nnz, colptr, rowind, a, perm_r, R1, C1);
-		
-		MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
-		if ( job == 5 && Equil ) {
-		    MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
-		    MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+		iinfo = zldperm_dist(job, m, nnz, colptr, rowind, a,
+                                perm_r, R1, C1);
+
+                MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );		
+		if ( iinfo == 0 ) {
+		    MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
+		    if ( job == 5 && Equil ) {
+		       MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
+		       MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+		   }
 		}
 	    } else {
-		MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
-		if ( job == 5 && Equil ) {
-		    MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
-		    MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+		MPI_Bcast( &iinfo, 1, mpi_int_t, 0, grid->comm );
+		if ( iinfo == 0 ) {
+		   MPI_Bcast( perm_r, m, mpi_int_t, 0, grid->comm );
+		   if ( job == 5 && Equil ) {
+		      MPI_Bcast( R1, m, MPI_DOUBLE, 0, grid->comm );
+		      MPI_Bcast( C1, n, MPI_DOUBLE, 0, grid->comm );
+		   }
 		}
 	    }
 
+	    if ( iinfo && job == 5) {
+	        SUPERLU_FREE(R1);
+	        SUPERLU_FREE(C1);
+   	    }
+
 #if ( PRNTlevel>=2 )
-	    dmin = dmach("Overflow");
+	    dmin = dmach_dist("Overflow");
 	    dsum = 0.0;
 	    dprod = 1.0;
 #endif
-	    if ( job == 5 ) {
+	    if ( iinfo == 0 ) {
+	      if ( job == 5 ) {
 		if ( Equil ) {
 		    for (i = 0; i < n; ++i) {
 			R1[i] = exp(R1[i]);
@@ -754,7 +775,7 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 		}
 		SUPERLU_FREE (R1);
 		SUPERLU_FREE (C1);
-	    } else { /* job = 2,3,4 */
+	      } else { /* job = 2,3,4 */
 		for (j = 0; j < n; ++j) {
 		    for (i = colptr[j]; i < colptr[j+1]; ++i) {
 			irow = rowind[i];
@@ -769,8 +790,11 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 				dprod *= slud_z_abs1(&a[i]);
 			}
 #endif
-		    }
-		}
+		    } /* end for i ... */
+		} /* end for j ... */
+              } /* end else */
+            } else { /* if iinfo != 0 */
+		for (i = 0; i < m; ++i) perm_r[i] = i;
 	    }
 
 #if ( PRNTlevel>=2 )
@@ -849,7 +873,7 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 
 	    stat->utime[SYMBFAC] = SuperLU_timer_() - t;
 
-	    if ( iinfo < 0 ) {
+	    if ( iinfo <= 0 ) {
 		QuerySpace_dist(n, -iinfo, Glu_freeable, &symb_mem_usage);
 #if ( PRNTlevel>=1 ) 
 		if ( !iam ) {
@@ -865,11 +889,13 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 			   symb_mem_usage.expansions);
 		}
 #endif
-	    } else {
-		if ( !iam ) {
+	    } else { /* symbfact out of memory */
+#if ( PRNTlevel>=1 )
+		if ( !iam )
 		    fprintf(stderr, "symbfact() error returns " IFMT "\n", iinfo);
-		    exit(-1);
-		}
+#endif
+                *info = iinfo;  
+                return;
 	    }
 	}
 
@@ -916,14 +942,11 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
 		       "\t\ttotal\t%.2f\tAvg\t%.2f\tMax\t%.2f\n",
 		       avg*1e-6, avg/grid->nprow/grid->npcol*1e-6, max*1e-6);
 		printf("\tNumber of tiny pivots: %10d\n", stat->TinyPivots);
+		printf(".. pzgstrf INFO = %d\n", *info);
 	    }
 	}
 #endif
     
-#if ( PRNTlevel>=2 )
-	if ( !iam ) printf(".. pzgstrf INFO = %d\n", *info);
-#endif
-
     } else if ( options->IterRefine ) { /* options->Fact==FACTORED */
 	/* Permute columns of A to form A*Pc' using the existing perm_c.
 	 * NOTE: rows of A were previously permuted to Pc*A.
@@ -934,7 +957,7 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
     /* ------------------------------------------------------------
        Compute the solution matrix X.
        ------------------------------------------------------------*/
-    if ( nrhs ) {
+    if ( nrhs && *info == 0 ) {
 
 	if ( !(b_work = doublecomplexMalloc_dist(n)) )
 	    ABORT("Malloc fails for b_work[]");
